@@ -8,7 +8,6 @@ module LLVM.FFI.Support.Host (
     FeatureMapRef,
     FeatureIterator,
     FeatureIteratorRef,
-    getHostCPUName,
     getHostFeatures,
     freeFeatures,
     getFirstFeature,
@@ -24,9 +23,6 @@ import Foreign.Ptr (Ptr)
 import Data.Typeable (Typeable)
 
 
-foreign import ccall unsafe "LLVMGetHostCPUName" getHostCPUName :: IO CString
-
-
 data FeatureMap
     deriving (Typeable)
 type FeatureMapRef = Ptr FeatureMap
